@@ -6,8 +6,7 @@ import itertools
 from .types import BaseType
 from .types.compound import ModelType
 from .types.serializable import Serializable
-from .exceptions import (BaseError, ValidationError, ModelValidationError,
-                         ConversionError, ModelConversionError)
+from .exceptions import BaseError, ModelValidationError
 from .transforms import allow_none, atoms, flatten, expand
 from .transforms import to_primitive, to_native, convert
 from .validate import validate
@@ -89,16 +88,16 @@ class ModelOptions(object):
 
 class ModelMeta(type):
     """
-    Meta class for Models. 
+    Meta class for Models.
     """
 
     def __new__(cls, name, bases, attrs):
         """
         This metaclass adds four attributes to host classes: cls._fields,
         cls._serializables, cls._validator_functions, and cls._options.
-        
+
         This function creates those attributes like this:
-        
+
         ``cls._fields`` is list of fields that are schematics types
         ``cls._serializables`` is a list of functions that are used to generate
         values during serialization
@@ -131,7 +130,7 @@ class ModelMeta(type):
 
         ### Parse meta options
         options = cls._read_options(name, bases, attrs)
-            
+
         ### Convert list of types into fields for new klass
         fields.sort(key=lambda i: i[1]._position_hint)
         for key, field in fields.iteritems():
@@ -165,7 +164,7 @@ class ModelMeta(type):
                     if not k.startswith("_") and not k == "klass":
                         options_members[k] = v
 
-        options_class = getattr(attrs, '__classoptions__', ModelOptions)
+        options_class = attrs.get('__optionsclass__', ModelOptions)
         if 'Options' in attrs:
             for k, v in inspect.getmembers(attrs['Options']):
                 if not k.startswith("_"):
@@ -208,7 +207,7 @@ class Model(object):
         if raw_data is None:
             raw_data = {}
         self._initial = raw_data
-        self._data = self.convert(raw_data)
+        self._data = self.convert(raw_data, strict=True)
 
     def validate(self, partial=False, strict=False):
         """
@@ -230,7 +229,7 @@ class Model(object):
         except BaseError as e:
             raise ModelValidationError(e.messages)
 
-    def convert(self, raw_data):
+    def convert(self, raw_data, **kw):
         """
         Converts the raw data into richer Python constructs according to the
         fields on the model
@@ -238,7 +237,7 @@ class Model(object):
         :param raw_data:
             The data to be converted
         """
-        return convert(self.__class__, raw_data)
+        return convert(self.__class__, raw_data, **kw)
 
     def to_native(self, role=None):
         return to_native(self.__class__, self, role=role)
@@ -295,13 +294,15 @@ class Model(object):
 
     def iter(self):
         return iter(self._fields)
-    
-    def __getitem__(self, name):
-        try:
-            return getattr(self, name)
-        except AttributeError:
-            pass
-        raise KeyError(name)
+
+    def keys(self):
+        return self._fields.keys()
+
+    def items(self):
+        return [(k, self.get(k)) for k in self._fields.iterkeys()]
+
+    def values(self):
+        return [self.get(k) for k in self._fields.iterkeys()]
 
     def get(self, key, default=None):
         try:
@@ -309,6 +310,13 @@ class Model(object):
         except KeyError:
             return default
 
+    def __getitem__(self, name):
+        try:
+            return getattr(self, name)
+        except AttributeError:
+            pass
+        raise KeyError(name)
+
     def __setitem__(self, name, value):
         if name not in self._data:
             raise KeyError(name)
@@ -322,10 +330,8 @@ class Model(object):
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
-            keys = self._fields
-
-            for key in keys:
-                if self[key] != other[key]:
+            for k in self._fields:
+                if self.get(k) != other.get(k):
                     return False
             return True
         return False
